"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class CustomerTypedDict(TypedDict):
    pass


class Customer(BaseModel):
    pass


class TenantTypedDict(TypedDict):
    pass


class Tenant(BaseModel):
    pass


class ThreadTypedDict(TypedDict):
    pass


class Thread(BaseModel):
    pass


class PlainCardRequestDtoTypedDict(TypedDict):
    timestamp: str
    card_keys: NotRequired[List[str]]
    customer: NotRequired[Nullable[CustomerTypedDict]]
    tenant: NotRequired[Nullable[TenantTypedDict]]
    thread: NotRequired[Nullable[ThreadTypedDict]]


class PlainCardRequestDto(BaseModel):
    timestamp: str

    card_keys: Annotated[Optional[List[str]], pydantic.Field(alias="cardKeys")] = None

    customer: OptionalNullable[Customer] = UNSET

    tenant: OptionalNullable[Tenant] = UNSET

    thread: OptionalNullable[Thread] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["cardKeys", "customer", "tenant", "thread"]
        nullable_fields = ["customer", "tenant", "thread"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
